@@ -109,24 +109,26 @@ sub get_class ( $self, $name ) {
 
     # name not contains '.' - this perl class name
     if ( index( $name, '.' ) == -1 ) {
+        my $colon_idx = index $name, '::';
 
-        # search by perl class name, related to the current namespace
-        if ( $self->{ctx}->{namespace} ) {
-            my $class_name = $Pcore::Ext::CFG->{perl_class}->{"$self->{ctx}->{namespace}::$name"};
+        if ( $colon_idx == -1 || $colon_idx > 0 ) {
 
-            return $Pcore::Ext::CFG->{class}->{$class_name} if $class_name;
+            # search by perl class name, related to the current namespace
+            if ( my $class_name = $Pcore::Ext::CFG->{perl_class}->{"$self->{ctx}->{namespace}::$name"} ) {
+                return $Pcore::Ext::CFG->{class}->{$class_name};
+            }
+
+            # search by full perl class name
+            if ( my $class_name = $Pcore::Ext::CFG->{perl_class}->{$name} ) {
+                return $Pcore::Ext::CFG->{class}->{$class_name};
+            }
         }
+        elsif ( $colon_idx == 0 ) {
 
-        # search by perl class name, related to the current Ext app namespace
-        if ( $self->{ctx}->{app_namespace} ) {
-            my $class_name = $Pcore::Ext::CFG->{perl_class}->{"$self->{ctx}->{app_namespace}::$name"};
-
-            return $Pcore::Ext::CFG->{class}->{$class_name} if $class_name;
-        }
-
-        # search by full perl class name
-        if ( my $class_name = $Pcore::Ext::CFG->{perl_class}->{$name} ) {
-            return $Pcore::Ext::CFG->{class}->{$class_name};
+            # search by perl class name, related to the app root Ext namespace
+            if ( my $class_name = $Pcore::Ext::CFG->{perl_class}->{"$self->{ctx}->{root_namespace}$name"} ) {
+                return $Pcore::Ext::CFG->{class}->{$class_name};
+            }
         }
     }
 
